@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
   code based on calligra autocorrection.
 
   This program is free software; you can redistribute it and/or modify it
@@ -604,8 +604,8 @@ QString AutoCorrection::autoDetectURL(const QString &_word) const
 
     bool secure = false;
     int link_type = 0;
-    int pos = word.indexOf(QStringLiteral("http://"));
-    int tmp_pos = word.indexOf(QStringLiteral("https://"));
+    int pos = word.indexOf(QLatin1String("http://"));
+    int tmp_pos = word.indexOf(QLatin1String("https://"));
 
     if (tmp_pos != -1 && pos == -1) {
         secure = true;
@@ -615,12 +615,12 @@ QString AutoCorrection::autoDetectURL(const QString &_word) const
         pos = tmp_pos;
     }
 
-    tmp_pos = word.indexOf(QStringLiteral("mailto:/"));
+    tmp_pos = word.indexOf(QLatin1String("mailto:/"));
     if ((tmp_pos < pos || pos == -1) && tmp_pos != -1) {
         pos = tmp_pos;
     }
-    tmp_pos = word.indexOf(QStringLiteral("ftp://"));
-    const int secureftp = word.indexOf(QStringLiteral("ftps://"));
+    tmp_pos = word.indexOf(QLatin1String("ftp://"));
+    const int secureftp = word.indexOf(QLatin1String("ftps://"));
     if (secureftp != -1 && tmp_pos == -1) {
         secure = true;
     }
@@ -628,21 +628,21 @@ QString AutoCorrection::autoDetectURL(const QString &_word) const
     if ((tmp_pos < pos || pos == -1) && tmp_pos != -1) {
         pos = tmp_pos;
     }
-    tmp_pos = word.indexOf(QStringLiteral("ftp."));
+    tmp_pos = word.indexOf(QLatin1String("ftp."));
 
     if ((tmp_pos < pos || pos == -1) && tmp_pos != -1) {
         pos = tmp_pos;
         link_type = 3;
     }
-    tmp_pos = word.indexOf(QStringLiteral("file:/"));
+    tmp_pos = word.indexOf(QLatin1String("file:/"));
     if ((tmp_pos < pos || pos == -1) && tmp_pos != -1) {
         pos = tmp_pos;
     }
-    tmp_pos = word.indexOf(QStringLiteral("news:"));
+    tmp_pos = word.indexOf(QLatin1String("news:"));
     if ((tmp_pos < pos || pos == -1) && tmp_pos != -1) {
         pos = tmp_pos;
     }
-    tmp_pos = word.indexOf(QStringLiteral("www."));
+    tmp_pos = word.indexOf(QLatin1String("www."));
 
     if ((tmp_pos < pos || pos == -1) && tmp_pos != -1 && word.indexOf(QLatin1Char('.'), tmp_pos + 4) != -1) {
         pos = tmp_pos;
@@ -672,7 +672,7 @@ QString AutoCorrection::autoDetectURL(const QString &_word) const
     if (pos != -1) {
         // A URL inside e.g. quotes (like "http://www.calligra.org" with the quotes) shouldn't include the quote in the URL.
         while (!word.at(word.length() - 1).isLetter() && !word.at(word.length() - 1).isDigit() && word.at(word.length() - 1) != QLatin1Char('/')) {
-            word.truncate(word.length() - 1);
+            word.chop(1);
         }
         word.remove(0, pos);
         QString newWord = word;
@@ -1059,7 +1059,7 @@ void AutoCorrection::readAutoCorrectionXmlFile(bool forceGlobal)
     const QStringList lst = QLocale::system().uiLanguages();
     if (!lst.isEmpty()) {
         kdelang = lst.at(0);
-        if (kdelang == QLatin1String("C")) {
+        if (kdelang == QLatin1Char('C')) {
             kdelang = QStringLiteral("en_US");
         }
     }
@@ -1074,14 +1074,14 @@ void AutoCorrection::readAutoCorrectionXmlFile(bool forceGlobal)
     //Look at local file:
     if (!forceGlobal) {
         if (!mAutoCorrectLang.isEmpty()) {
-            localFileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("autocorrect/custom-") + mAutoCorrectLang + QLatin1String(".xml"));
+            localFileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("autocorrect/custom-") + mAutoCorrectLang + QLatin1String(".xml"));
         } else {
             if (!kdelang.isEmpty()) {
-                localFileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("autocorrect/custom-") + kdelang + QLatin1String(".xml"));
+                localFileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("autocorrect/custom-") + kdelang + QLatin1String(".xml"));
             }
             if (localFileName.isEmpty() && kdelang.contains(QLatin1Char('_'))) {
                 kdelang.remove(QRegularExpression(QStringLiteral("_.*")));
-                localFileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("autocorrect/custom-") + kdelang + QLatin1String(".xml"));
+                localFileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("autocorrect/custom-") + kdelang + QLatin1String(".xml"));
             }
         }
     }
@@ -1091,15 +1091,15 @@ void AutoCorrection::readAutoCorrectionXmlFile(bool forceGlobal)
         if (mAutoCorrectLang == QLatin1String("en_US")) {
             fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("autocorrect/autocorrect.xml"));
         } else {
-            fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("autocorrect/") + mAutoCorrectLang + QLatin1String(".xml"));
+            fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("autocorrect/") + mAutoCorrectLang + QLatin1String(".xml"));
         }
     } else {
         if (fname.isEmpty() && !kdelang.isEmpty()) {
-            fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("autocorrect/") + kdelang + QLatin1String(".xml"));
+            fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("autocorrect/") + kdelang + QLatin1String(".xml"));
         }
         if (fname.isEmpty() && kdelang.contains(QLatin1Char('_'))) {
             kdelang.remove(QRegularExpression(QStringLiteral("_.*")));
-            fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("autocorrect/") + kdelang + QLatin1String(".xml"));
+            fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("autocorrect/") + kdelang + QLatin1String(".xml"));
         }
     }
     if (fname.isEmpty()) {
