@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -42,8 +43,6 @@ class PimCommon::AutoCorrectionWidgetPrivate
 public:
     AutoCorrectionWidgetPrivate()
         : ui(new Ui::AutoCorrectionWidget)
-        , mAutoCorrection(nullptr)
-        , mWasChanged(false)
     {
     }
 
@@ -119,7 +118,7 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent)
     slotEnableDisableAbreviationList();
     slotEnableDisableTwoUpperEntry();
 
-    QMenu *menu = new QMenu();
+    QMenu *menu = new QMenu(this);
     d->ui->importAutoCorrection->setMenu(menu);
 
     QAction *act = new QAction(i18n("LibreOffice Autocorrection"), this);
