@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,6 +23,10 @@
 #include "pimcommon_export.h"
 class QDialogButtonBox;
 namespace PimCommon {
+/**
+ * @brief The ConfigurePluginDialog class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMON_EXPORT ConfigurePluginDialog : public QDialog
 {
     Q_OBJECT
@@ -29,7 +34,7 @@ public:
     explicit ConfigurePluginDialog(QWidget *parent = nullptr);
     ~ConfigurePluginDialog();
 
-    void initLayout();
+    void initLayout(bool addSpacer = false);
 
 protected:
     void showHelp(const QString &name, const QString &anchor);
