@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,7 +20,6 @@
 #include <QStackedWidget>
 #include <QTest>
 #include <QStandardPaths>
-#include <KActionCollection>
 
 CustomToolsWidgetNgTest::CustomToolsWidgetNgTest(QObject *parent)
     : QObject(parent)
@@ -34,7 +33,7 @@ CustomToolsWidgetNgTest::~CustomToolsWidgetNgTest()
 
 void CustomToolsWidgetNgTest::shouldHaveDefaultValue()
 {
-    PimCommon::CustomToolsWidgetNg widget(new KActionCollection(this));
+    PimCommon::CustomToolsWidgetNg widget;
     widget.show();
 
     QStackedWidget *stackWidget = widget.findChild<QStackedWidget *>(QStringLiteral("stackedwidget"));
