@@ -1,9 +1,10 @@
 /*
-  Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
+  Copyright (C) 2017-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,6 +23,10 @@
 #include "pimcommon_export.h"
 namespace PimCommon {
 class LogActivitiesManagerPrivate;
+/**
+ * @brief The LogActivitiesManager class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMON_EXPORT LogActivitiesManager : public QObject
 {
     Q_OBJECT
@@ -33,7 +38,7 @@ public:
 
     void appendLog(const QString &str);
 
-    QString log() const;
+    Q_REQUIRED_RESULT QString log() const;
 
     void clear();
 
