@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,7 @@
 
 #include "shareserviceurlmanagertest.h"
 #include "../shareserviceurlmanager.h"
-#include <qtest.h>
+#include <QTest>
 #include <kactionmenu.h>
 #include <QMenu>
 ShareServiceUrlManagerTest::ShareServiceUrlManagerTest(QObject *parent)
@@ -58,11 +58,6 @@ void ShareServiceUrlManagerTest::shouldGenerateServiceUrl_data()
     QTest::newRow("title and valid link (twitter)") << QStringLiteral("kde") << QStringLiteral("http://www.kde.org") << PimCommon::ShareServiceUrlManager::Twitter
                                                     << QUrl(QStringLiteral("https://twitter.com/share?url=http://www.kde.org&text=kde")) << true;
 
-    QTest::newRow("no title but valid link (googleplus)") << QString() << QStringLiteral("http://www.kde.org") << PimCommon::ShareServiceUrlManager::GooglePlus
-                                                          << QUrl(QStringLiteral("https://plus.google.com/share?url=http://www.kde.org")) << true;
-    QTest::newRow("title and valid link (googleplus)") << QStringLiteral("kde") << QStringLiteral("http://www.kde.org") << PimCommon::ShareServiceUrlManager::GooglePlus
-                                                       << QUrl(QStringLiteral("https://plus.google.com/share?url=http://www.kde.org")) << true;
-
     QTest::newRow("no title but valid link (mailto)") << QString() << QStringLiteral("http://www.kde.org") << PimCommon::ShareServiceUrlManager::MailTo
                                                       << QUrl(QStringLiteral("mailto:?subject&body=http://www.kde.org")) << true;
     QTest::newRow("title and valid link (mailto)") << QStringLiteral("kde") << QStringLiteral("http://www.kde.org") << PimCommon::ShareServiceUrlManager::MailTo
