@@ -1,10 +1,11 @@
 /*
 
-  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
-  The program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,12 +18,11 @@
 */
 
 #include "translatorwidget.h"
-#include "widgets/minimumcombobox.h"
 #include "translatorutil.h"
 #include "googletranslator.h"
 #include "kpimtextedit/plaintexteditorwidget.h"
-#include "Libkdepim/ProgressIndicatorWidget"
 #include <PimCommon/NetworkManager>
+#include <KBusyIndicatorWidget>
 
 #include <QPushButton>
 #include <KLocalizedString>
@@ -33,7 +33,7 @@
 
 #include <QMimeData>
 #include <QIcon>
-
+#include <QComboBox>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include <QLabel>
@@ -67,12 +67,12 @@ public:
     TranslatorTextEdit *inputText = nullptr;
     KPIMTextEdit::PlainTextEditorWidget *translatedText = nullptr;
     TranslatorResultTextEdit *translatorResultTextEdit = nullptr;
-    MinimumComboBox *from = nullptr;
-    MinimumComboBox *to = nullptr;
+    QComboBox *from = nullptr;
+    QComboBox *to = nullptr;
     QPushButton *translate = nullptr;
     QPushButton *clear = nullptr;
     PimCommon::GoogleTranslator *abstractTranslator = nullptr;
-    KPIM::ProgressIndicatorWidget *progressIndictor = nullptr;
+    KBusyIndicatorWidget *progressIndicator = nullptr;
     QPushButton *invert = nullptr;
     QSplitter *splitter = nullptr;
     bool languageSettingsChanged = false;
@@ -216,7 +216,7 @@ void TranslatorWidget::init()
     connect(d->abstractTranslator, &PimCommon::GoogleTranslator::translateFailed, this, &TranslatorWidget::slotTranslateFailed);
 
     QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(2);
+    layout->setContentsMargins(0, 0, 0, 0);
     QHBoxLayout *hboxLayout = new QHBoxLayout;
     QToolButton *closeBtn = new QToolButton(this);
     closeBtn->setObjectName(QStringLiteral("close-button"));
@@ -233,13 +233,15 @@ void TranslatorWidget::init()
 
     QLabel *label = new QLabel(i18nc("Translate from language", "From:"));
     hboxLayout->addWidget(label);
-    d->from = new MinimumComboBox;
+    d->from = new QComboBox;
+    d->from->setMinimumWidth(50);
     d->from->setObjectName(QStringLiteral("from"));
     hboxLayout->addWidget(d->from);
 
     label = new QLabel(i18nc("Translate to language", "To:"));
     hboxLayout->addWidget(label);
-    d->to = new MinimumComboBox;
+    d->to = new QComboBox;
+    d->to->setMinimumWidth(50);
     d->to->setObjectName(QStringLiteral("to"));
 
     hboxLayout->addWidget(d->to);
@@ -277,8 +279,8 @@ void TranslatorWidget::init()
         connect(debugButton, &QPushButton::clicked, this, &TranslatorWidget::slotDebug);
     }
 
-    d->progressIndictor = new KPIM::ProgressIndicatorWidget(this);
-    hboxLayout->addWidget(d->progressIndictor);
+    d->progressIndicator = new KBusyIndicatorWidget(this);
+    hboxLayout->addWidget(d->progressIndicator);
 
     hboxLayout->addItem(new QSpacerItem(5, 5, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum));
 
@@ -289,7 +291,7 @@ void TranslatorWidget::init()
     d->inputText = new TranslatorTextEdit(this);
     KPIMTextEdit::PlainTextEditorWidget *editorWidget = new KPIMTextEdit::PlainTextEditorWidget(d->inputText);
     d->inputText->setObjectName(QStringLiteral("inputtext"));
-    d->inputText->setPlaceholderText(i18n("Drag text that you want to translate."));
+    d->inputText->setPlaceholderText(i18n("Drag text that you want to translate. (Be careful text will be send to Google Server)."));
     connect(d->inputText, &TranslatorTextEdit::textChanged, this, &TranslatorWidget::slotTextChanged);
     connect(d->inputText, &TranslatorTextEdit::translateText, this, &TranslatorWidget::slotTranslate);
 
@@ -307,13 +309,13 @@ void TranslatorWidget::init()
     slotFromLanguageChanged(0, true);
     slotTextChanged();
     readConfig();
-    connect(d->from, QOverload<int>::of(&MinimumComboBox::currentIndexChanged), this, [this](int val) {
+    connect(d->from, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this](int val) {
         slotFromLanguageChanged(val, false);
     });
-    connect(d->from, QOverload<int>::of(&MinimumComboBox::currentIndexChanged), this, &TranslatorWidget::slotConfigChanged);
+    connect(d->from, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &TranslatorWidget::slotConfigChanged);
 
-    connect(d->to, QOverload<int>::of(&MinimumComboBox::currentIndexChanged), this, &TranslatorWidget::slotConfigChanged);
-    connect(d->to, QOverload<int>::of(&MinimumComboBox::currentIndexChanged), this, &TranslatorWidget::slotTranslate);
+    connect(d->to, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &TranslatorWidget::slotConfigChanged);
+    connect(d->to, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &TranslatorWidget::slotTranslate);
 
     hide();
     setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
@@ -370,7 +372,7 @@ void TranslatorWidget::slotTranslate()
     const QString from = d->from->itemData(d->from->currentIndex()).toString();
     const QString to = d->to->itemData(d->to->currentIndex()).toString();
     d->translate->setEnabled(false);
-    d->progressIndictor->start();
+    d->progressIndicator->show();
 
     d->abstractTranslator->setFrom(from);
     d->abstractTranslator->setTo(to);
@@ -381,7 +383,7 @@ void TranslatorWidget::slotTranslate()
 void TranslatorWidget::slotTranslateDone()
 {
     d->translate->setEnabled(true);
-    d->progressIndictor->stop();
+    d->progressIndicator->hide();
     d->translatorResultTextEdit->setResultFailed(false);
     d->translatorResultTextEdit->setPlainText(d->abstractTranslator->resultTranslate());
 }
@@ -389,7 +391,7 @@ void TranslatorWidget::slotTranslateDone()
 void TranslatorWidget::slotTranslateFailed(bool signalFailed, const QString &message)
 {
     d->translate->setEnabled(true);
-    d->progressIndictor->stop();
+    d->progressIndicator->hide();
     d->translatorResultTextEdit->setResultFailed(signalFailed);
     d->translatorResultTextEdit->clear();
     if (!message.isEmpty()) {
@@ -429,7 +431,7 @@ void TranslatorWidget::slotCloseWidget()
     }
     d->inputText->clear();
     d->translatorResultTextEdit->clear();
-    d->progressIndictor->stop();
+    d->progressIndicator->hide();
     if (d->standalone) {
         hide();
     }
