@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -24,6 +24,7 @@
 #include "aclutils_p.h"
 #include "pimcommonakonadi_debug.h"
 #include <AkonadiCore/ServerManager>
+#include <KEmailAddress>
 
 #include "imapaclattribute.h"
 #include "job/fetchrecursivecollectionsjob.h"
@@ -31,25 +32,89 @@
 #include <KLocalizedString>
 #include <QDBusInterface>
 #include <QDBusReply>
+#include <ContactGroupSearchJob>
+#include <ContactGroupExpandJob>
 #include <AkonadiCore/CollectionModifyJob>
+#include <KContacts/Addressee>
 
 using namespace PimCommon;
+//#define SEARCHCONTACT_AKONADI 1
 
 AclModifyJob::AclModifyJob(QObject *parent)
     : QObject(parent)
 {
+    connect(this, &AclModifyJob::searchContactDone, this, &AclModifyJob::slotModifyAcl);
+    connect(this, &AclModifyJob::searchNextContact, this, &AclModifyJob::searchContact);
 }
 
 AclModifyJob::~AclModifyJob()
 {
 }
 
+void AclModifyJob::searchContact()
+{
+    const QMap<QByteArray, KIMAP::Acl::Rights>::const_iterator itEnd = mCurrentRight.cend();
+    if (mIt != itEnd) {
+        Akonadi::ContactGroupSearchJob *searchJob = new Akonadi::ContactGroupSearchJob(this);
+        searchJob->setQuery(Akonadi::ContactGroupSearchJob::Name, QString::fromLatin1(mIt.key()));
+        searchJob->setLimit(1);
+        connect(searchJob, &Akonadi::ContactGroupSearchJob::result, this, &AclModifyJob::slotGroupSearchResult);
+    } else {
+        Q_EMIT searchContactDone();
+    }
+}
+
+void AclModifyJob::slotGroupSearchResult(KJob *job)
+{
+    Akonadi::ContactGroupSearchJob *searchJob = qobject_cast<Akonadi::ContactGroupSearchJob *>(job);
+    if (!searchJob->contactGroups().isEmpty()) {   // it has been a distribution list
+        Akonadi::ContactGroupExpandJob *expandJob
+            = new Akonadi::ContactGroupExpandJob(searchJob->contactGroups().at(0), this);
+        if (expandJob->exec()) {
+            const KContacts::Addressee::List lstContacts = expandJob->contacts();
+            for (const KContacts::Addressee &contact : lstContacts) {
+                const QByteArray rawEmail
+                    = KEmailAddress::extractEmailAddress(contact.preferredEmail().toUtf8());
+                if (!rawEmail.isEmpty()) {
+                    mNewRight[ rawEmail ] = mIt.value();
+                }
+            }
+        }
+    } else { // it has been a normal contact
+        const QByteArray rawEmail = KEmailAddress::extractEmailAddress(mIt.key());
+        if (!rawEmail.isEmpty()) {
+            mNewRight[ rawEmail ] = mIt.value();
+        }
+    }
+    mIt++;
+    Q_EMIT searchNextContact();
+}
+
 void AclModifyJob::start()
 {
     if (!mTopLevelCollection.isValid()) {
         deleteLater();
         return;
     }
+#ifdef SEARCHCONTACT_AKONADI
+    mIt = mCurrentRight.cbegin();
+    searchContact();
+#else
+    const QMap<QByteArray, KIMAP::Acl::Rights> rights = mCurrentRight;
+    QMap<QByteArray, KIMAP::Acl::Rights>::const_iterator it = rights.cbegin();
+    const QMap<QByteArray, KIMAP::Acl::Rights>::const_iterator itEnd = rights.cend();
+    for (; it != itEnd; ++it) {
+        const QByteArray rawEmail = KEmailAddress::extractEmailAddress(it.key());
+        if (!rawEmail.isEmpty()) {
+            mNewRight[rawEmail] = it.value();
+        }
+    }
+    slotModifyAcl();
+#endif
+}
+
+void AclModifyJob::slotModifyAcl()
+{
     mCurrentIndex = 0;
     if (mRecursive) {
         PimCommon::FetchRecursiveCollectionsJob *fetchJob = new PimCommon::FetchRecursiveCollectionsJob(this);
@@ -62,7 +127,7 @@ void AclModifyJob::start()
     }
 }
 
-bool AclModifyJob::canAdministrate(PimCommon::ImapAclAttribute *attribute, const Akonadi::Collection &collection) const
+bool AclModifyJob::canAdministrate(const PimCommon::ImapAclAttribute *attribute, const Akonadi::Collection &collection) const
 {
     if (!attribute || !collection.isValid()) {
         return false;
@@ -73,9 +138,9 @@ bool AclModifyJob::canAdministrate(PimCommon::ImapAclAttribute *attribute, const
     if (resource.contains(QLatin1String("akonadi_kolabproxy_resource"))) {
         const QString basename = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent,
                                                                           QStringLiteral("akonadi_kolabproxy_resource"));
-        QDBusInterface interface(basename, QLatin1String("/KolabProxy"));
+        QDBusInterface interface(basename, QStringLiteral("/KolabProxy"));
         if (interface.isValid()) {
-            QDBusReply<QString> reply = interface.call(QLatin1String("imapResourceForCollection"), collection.remoteId().toLongLong());
+            QDBusReply<QString> reply = interface.call(QStringLiteral("imapResourceForCollection"), collection.remoteId().toLongLong());
             if (reply.isValid()) {
                 resource = reply;
             }
@@ -111,13 +176,19 @@ bool AclModifyJob::canAdministrate(PimCommon::ImapAclAttribute *attribute, const
     return rights[ imapUserName.toUtf8() ] & KIMAP::Acl::Admin;
 }
 
+void AclModifyJob::setCurrentRight(const QMap<QByteArray, KIMAP::Acl::Rights> &currentRight)
+{
+    mCurrentRight = currentRight;
+}
+
 void AclModifyJob::changeAcl(const Akonadi::Collection &collection)
 {
     if (collection.hasAttribute<PimCommon::ImapAclAttribute>()) {
-        PimCommon::ImapAclAttribute *attribute = collection.attribute<PimCommon::ImapAclAttribute>();
-        if (canAdministrate(attribute, collection)) {
+        Akonadi::Collection mutableCollection = collection;
+        PimCommon::ImapAclAttribute *attribute = mutableCollection.attribute<PimCommon::ImapAclAttribute>();
+        if (canAdministrate(attribute, mutableCollection)) {
             attribute->setRights(mNewRight);
-            Akonadi::CollectionModifyJob *modifyJob = new Akonadi::CollectionModifyJob(collection);
+            Akonadi::CollectionModifyJob *modifyJob = new Akonadi::CollectionModifyJob(mutableCollection);
             connect(modifyJob, &KJob::result, this, &AclModifyJob::slotModifyDone);
         }
     } else {
@@ -148,7 +219,7 @@ void AclModifyJob::slotFetchCollectionFinished(const Akonadi::Collection::List &
     QStringList folderNames;
     for (const Akonadi::Collection &col : collectionList) {
         if (col.hasAttribute<PimCommon::ImapAclAttribute>()) {
-            PimCommon::ImapAclAttribute *attribute = col.attribute<PimCommon::ImapAclAttribute>();
+            const PimCommon::ImapAclAttribute *attribute = col.attribute<PimCommon::ImapAclAttribute>();
             if (canAdministrate(attribute, col)) {
                 QString fullName;
                 bool parentFound;
@@ -204,8 +275,3 @@ void AclModifyJob::setRecursive(bool recursive)
 {
     mRecursive = recursive;
 }
-
-void AclModifyJob::setNewRights(const QMap<QByteArray, KIMAP::Acl::Rights> &right)
-{
-    mNewRight = right;
-}
